@@ -119,12 +119,13 @@ def test_sync_without_self(project, working_set):
 
 
 def test_sync_with_index_change(project, index):
-    project.meta["requires-python"] = ">=3.6"
-    project.meta["dependencies"] = ["future-fstrings"]
-    project.write_pyproject()
+    project.project_config["pypi.url"] = "https://my.pypi.org/simple"
+    project.pyproject.metadata["requires-python"] = ">=3.6"
+    project.pyproject.metadata["dependencies"] = ["future-fstrings"]
+    project.pyproject.write()
     index[
-        "future-fstrings"
-    ] = """
+        "/simple/future-fstrings/"
+    ] = b"""
     <html>
     <body>
         <h1>future-fstrings</h1>
@@ -134,14 +135,14 @@ def test_sync_with_index_change(project, index):
         </a>
     </body>
     </html>
-    """.encode()
+    """
     actions.do_lock(project)
     file_hashes = project.lockfile["metadata"]["files"]["future-fstrings 1.2.0"]
     assert [e["hash"] for e in file_hashes] == [
         "sha256:90e49598b553d8746c4dc7d9442e0359d038c3039d802c91c0a55505da318c63"
     ]
     # Mimic the CDN inconsistences of PyPI simple index. See issues/596.
-    del index["future-fstrings"]
+    del index["/simple/future-fstrings/"]
     actions.do_sync(project, no_self=True)
 
 
@@ -176,7 +177,7 @@ def test_install_with_lockfile(project, invoke, working_set, repository):
 def test_install_with_dry_run(project, invoke, repository):
     project.add_dependencies({"pytz": parse_requirement("pytz")}, "default")
     result = invoke(["install", "--dry-run"], obj=project)
-    project._lockfile = None
+    project.lockfile.reload()
     assert "pytz" not in project.locked_repository.all_candidates
     assert "pytz 2019.3" in result.output
 
@@ -189,3 +190,29 @@ def test_install_check(invoke, project, repository):
     project.add_dependencies({"requests": parse_requirement("requests>=2.0")})
     result = invoke(["install", "--check"], obj=project)
     assert result.exit_code == 1
+
+
+@pytest.mark.usefixtures("repository")
+def test_sync_with_pure_option(project, working_set, invoke):
+    project.add_dependencies({"requests": parse_requirement("requests>=2.0")})
+    project.add_dependencies({"django": parse_requirement("django")}, "web", True)
+    invoke(["install"], obj=project, strict=True)
+    assert all(
+        p in working_set for p in ("requests", "urllib3", "django", "pytz")
+    ), list(working_set)
+    actions.do_sync(project, dev=False, only_keep=True)
+    assert "requests" in working_set
+    assert "urllib3" in working_set
+    assert "django" not in working_set
+
+
+@pytest.mark.usefixtures("repository")
+def test_install_referencing_self_package(project, working_set, invoke):
+    project.add_dependencies({"pytz": parse_requirement("pytz")}, to_group="tz")
+    project.add_dependencies({"urllib3": parse_requirement("urllib3")}, to_group="web")
+    project.add_dependencies(
+        {"test-project": parse_requirement("test-project[tz,web]")}, to_group="all"
+    )
+    invoke(["install", "-Gall"], obj=project, strict=True)
+    assert "pytz" in working_set
+    assert "urllib3" in working_set
