@@ -12,22 +12,20 @@ def test_remove_command(project, invoke, mocker):
 
 
 @pytest.mark.usefixtures("repository", "working_set", "vcs")
-def test_remove_both_normal_and_editable_packages(project, is_dev):
+def test_remove_editable_packages_while_keeping_normal(project):
     project.environment.python_requires = PySpecSet(">=3.6")
-    actions.do_add(project, is_dev, packages=["demo"])
+    actions.do_add(project, packages=["demo"])
     actions.do_add(
         project,
-        is_dev,
+        True,
         editables=["git+https://github.com/test-root/demo.git#egg=demo"],
     )
-    group = (
-        project.tool_settings["dev-dependencies"]["dev"]
-        if is_dev
-        else project.meta["dependencies"]
-    )
-    actions.do_remove(project, is_dev, packages=["demo"])
-    assert not group
-    assert "demo" not in project.locked_repository.all_candidates
+    dev_group = project.pyproject.settings["dev-dependencies"]["dev"]
+    default_group = project.pyproject.metadata["dependencies"]
+    actions.do_remove(project, True, packages=["demo"])
+    assert not dev_group
+    assert len(default_group) == 1
+    assert not project.locked_repository.all_candidates["demo"].req.editable
 
 
 @pytest.mark.usefixtures("repository")
@@ -74,7 +72,7 @@ def test_remove_package_exist_in_multi_groups(project, working_set):
     actions.do_remove(project, dev=True, packages=["urllib3"])
     assert all(
         "urllib3" not in line
-        for line in project.tool_settings["dev-dependencies"]["dev"]
+        for line in project.pyproject.settings["dev-dependencies"]["dev"]
     )
     assert "urllib3" in working_set
     assert "requests" in working_set
@@ -87,3 +85,19 @@ def test_add_remove_no_package(project):
 
     with pytest.raises(PdmUsageError):
         actions.do_remove(project, packages=())
+
+
+@pytest.mark.usefixtures("repository", "working_set")
+def test_remove_package_wont_break_toml(project_no_init):
+    project_no_init.pyproject._path.write_text(
+        """
+[project]
+dependencies = [
+    "requests",
+    # this is a comment
+]
+"""
+    )
+    project_no_init.pyproject.reload()
+    actions.do_remove(project_no_init, packages=["requests"])
+    assert project_no_init.pyproject.metadata["dependencies"] == []
